@@ -29,7 +29,7 @@
      Add -r flag: Keith Owens <kaos@ocs.com.au> October 1999.
    */
 
-#ident "$Id: depmod.c 1.4 Mon, 22 Nov 1999 01:38:27 +1100 keith $"
+#ident "$Id: depmod.c 1.5 Tue, 07 Dec 1999 21:42:01 +1100 keith $"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -54,7 +54,7 @@
 #include "config.h"
 #include "modstat.h"
 
-#if defined(COMBINE_sparc)
+#if defined(COMMON_sparc)
 #if defined(ARCH_sparc)
 #define main depmod32_main
 #elif defined(ARCH_sparc64)
@@ -709,7 +709,7 @@ int main(int argc, char *argv[])
 	return ret;
 }
 
-#if defined(COMBINE_sparc) && defined(ARCH_sparc)
+#if defined(COMMON_sparc) && defined(ARCH_sparc)
 
 #undef main
 
