@@ -35,9 +35,13 @@
      Ksymoops support: Keith Owens <kaos@ocs.com.au> August 1999.
 
      Add -r flag: Keith Owens <kaos@ocs.com.au> October 1999.
+
+     More flexible recognition of the way the utility was called.
+     Suggested by Stepan Kasal, implemented in a different way by Keith
+     Owens <kaos@ocs.com.au> December 1999.
    */
 
-#ident "$Id: insmod.c 1.6 Mon, 22 Nov 1999 01:38:27 +1100 keith $"
+#ident "$Id: insmod.c 1.9 Sat, 11 Dec 1999 04:17:50 +1100 keith $"
 
 #include <sys/types.h>
 #include <stdlib.h>
@@ -61,7 +65,7 @@
 #include "modstat.h"
 #include "config.h"
 
-#if defined(COMBINE_sparc)
+#if defined(COMMON_sparc)
 #if defined(ARCH_sparc)
 #define main insmod32_main
 #elif defined(ARCH_sparc64)
@@ -1057,8 +1061,11 @@ static int old_init_module(const char *m_name, struct obj_file *f, unsigned long
 /* end compat */
 /************************************************************************/
 
+#if defined(COMMON_sparc) && !defined(ARCH_sparc)
+extern void insmod_usage(void);
+#else
 /* Print the usage message. */
-static void usage(void)
+void insmod_usage(void)
 {
 	fputs("Usage:\n"
 	      "insmod [-fkmopsvVxXyY] [-o name] [-P prefix] module [[sym=value]...]\n"
@@ -1085,6 +1092,7 @@ static void usage(void)
 	      ,stderr);
 	exit(1);
 }
+#endif
 
 int main(int argc, char **argv)
 {
@@ -1188,12 +1196,12 @@ int main(int argc, char **argv)
 			set_ncv_prefix(optarg);
 			break;
 		default:
-			usage();
+			insmod_usage();
 			break;
 		}
 
 	if (optind >= argc) {
-		usage();
+		insmod_usage();
 	}
 	filename = argv[optind++];
 
@@ -1397,7 +1405,7 @@ int main(int argc, char **argv)
 	return exit_status;
 }
 
-#if defined(COMBINE_sparc) && defined(ARCH_sparc)
+#if defined(COMMON_sparc) && defined(ARCH_sparc)
 extern int insmod64_main(int argc, char **argv);
 
 #undef main
@@ -1418,7 +1426,7 @@ int main(int argc, char **argv)
 
 #endif
 
-#if !defined(COMBINE_sparc) || !defined(ARCH_sparc64)
+#if !defined(COMMON_sparc) || !defined(ARCH_sparc64)
 #if defined(COMBINE_rmmod) || defined(COMBINE_modprobe) || defined(COMBINE_ksyms) || defined(COMBINE_lsmod)
 
 #undef main
@@ -1442,22 +1450,22 @@ int main(int argc, char **argv)
 
 	p = p ? p + 1 : argv[0];
 
-	if (strcmp(p, "insmod") == 0 || strcmp(p, "insmod.static") == 0)
+	if (strstr(p, "insmod"))
 		return insmod_main(argc, argv);
 #ifdef COMBINE_modprobe
-	else if (strcmp(p, "modprobe") == 0)
+	else if (strstr(p, "modprobe"))
 		return modprobe_main(argc, argv);
 #endif
 #ifdef COMBINE_rmmod
-	else if (strcmp(p, "rmmod") == 0)
+	else if (strstr(p, "rmmod"))
 		return rmmod_main(argc, argv);
 #endif
 #ifdef COMBINE_ksyms
-	else if (strcmp(p, "ksyms") == 0)
+	else if (strstr(p, "ksyms"))
 		return ksyms_main(argc, argv);
 #endif
 #ifdef COMBINE_lsmod
-	else if (strcmp(p, "lsmod") == 0)
+	else if (strstr(p, "lsmod"))
 		return lsmod_main(argc, argv);
 #endif
 	else {
