@@ -27,7 +27,7 @@
  * unified module path handling: Bjorn Ekwall <bj0rn@blox.se> February 1999
  */
 
-#ident "$Id: modinfo.c 1.2 Mon, 22 Nov 1999 01:38:27 +1100 keith $"
+#ident "$Id: modinfo.c 1.4 Sat, 11 Dec 1999 04:17:50 +1100 keith $"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -45,11 +45,11 @@
 #include "version.h"
 #include "config.h"
 
-#if defined(COMBINE_sparc)
+#if defined(COMMON_sparc)
 #if defined(ARCH_sparc)
-#define main modinfo32_main
+extern int show_module_info_64(char *filename, char *fmtstr, int do_parameters);
 #elif defined(ARCH_sparc64)
-#define main modinfo64_main
+#define show_module_info show_module_info_64
 #endif
 #endif
 
@@ -275,7 +275,7 @@ static void show_module_parameters(struct obj_file *f)
 	}
 }
 
-static int show_module_info(char *filename, char *fmtstr, int do_parameters)
+int show_module_info(char *filename, char *fmtstr, int do_parameters)
 {
 	FILE *fp;
 	struct obj_file *f;
@@ -310,7 +310,8 @@ static int show_module_info(char *filename, char *fmtstr, int do_parameters)
 	return 0;
 }
 
-static void usage(void)
+#if !defined(COMMON_sparc) || defined(ARCH_sparc)
+void usage(void)
 {
 	printf("usage: modinfo <parameters> <module>\n");
 	printf("  -a, --author            display module author\n");
@@ -336,6 +337,9 @@ int main(int argc, char *argv[])
 	};
 	int do_parameters = 0, opt;
 	char *fmtstr = NULL;
+#if defined(COMMON_sparc)
+	struct utsname u;
+#endif
 
 	while ((opt = getopt_long(argc, argv, "adq:pVh",
 				  &long_opts[0], NULL)) != EOF)
@@ -367,26 +371,16 @@ int main(int argc, char *argv[])
 	}
 	error_file = "modinfo";
 
+#if defined(COMMON_sparc)
+	if (!uname (&u) && !strcmp (u.machine, "sparc64"))
+	    while (optind < argc)
+		show_module_info_64(argv[optind++], fmtstr, do_parameters);
+	else
+#endif
 	while (optind < argc)
 		show_module_info(argv[optind++], fmtstr, do_parameters);
 
 	return 0;
 }
 
-#if defined(COMBINE_sparc) && defined(ARCH_sparc)
-
-#undef main
-
-extern int modinfo64_main(int argc, char **argv);
-
-int
-main(int argc, char **argv)
-{
-	struct utsname u;
-  
-	if (!uname (&u) && !strcmp (u.machine, "sparc64"))
-		return modinfo64_main(argc, argv);
-	else
-		return modinfo32_main(argc, argv);
-}
-#endif
+#endif /* !defined(COMMON_sparc) || defined(ARCH_sparc) */
