@@ -24,9 +24,10 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ident "$Id: rmmod.c 1.2 Wed, 25 Aug 1999 17:22:12 +1000 keith $"
+#ident "$Id: rmmod.c 1.5 Sun, 21 Nov 1999 15:19:53 +1100 keith $"
 
 #include <errno.h>
+#include <malloc.h>
 #include <unistd.h>
 
 #include "module.h"
@@ -49,9 +50,8 @@ int main(int argc, char **argv)
 	int j;
 	int ret = 0;
 	int recursive = 0;
-	size_t number;
-	size_t bufsize;
-	char *module_names;
+	size_t n_module_names;
+	char *module_names = NULL;
 
 	error_file = "rmmod";
 
@@ -60,14 +60,10 @@ int main(int argc, char **argv)
 	 * gives no indication that any modules were deleted so we have to
 	 * do it the hard way.
 	 */
-	module_names = xmalloc(bufsize = 256);
-	while (query_module(NULL, QM_MODULES, module_names, bufsize, &number)) {
-		if (errno != ENOSPC) {
-			error("QM_MODULES: %m\n");
-			return 0;
-		}
-		module_names = xrealloc(module_names, bufsize = number);
-	}
+	get_kernel_info(0); 
+	module_names = xmalloc(l_module_name_list);
+	memcpy(module_names, module_name_list, l_module_name_list);
+	n_module_names = n_module_stat;
 
 	while ((i = getopt(argc, argv, "arsV")) != EOF)
 		switch (i) {
@@ -75,10 +71,12 @@ int main(int argc, char **argv)
 			/* Remove all unused modules and stacks.  */
 			if (delete_module(NULL)) {
 				perror("rmmod");
-				snap_shot(module_names, number);
+				snap_shot(module_names, n_module_names);
+				free(module_names);
 				return 1;
 			}
-			snap_shot(module_names, number);
+			snap_shot(module_names, n_module_names);
+			free(module_names);
 			return 0;
 
 		case 'r':
@@ -111,7 +109,8 @@ int main(int argc, char **argv)
 				perror(argv[1]);
 			}
 		}
-		snap_shot(module_names, number);
+		snap_shot(module_names, n_module_names);
+		free(module_names);
 		return ret ? 1 : 0;
 	}
 
@@ -175,6 +174,7 @@ int main(int argc, char **argv)
 		}
 	}
 
-	snap_shot(module_names, number);
+	snap_shot(module_names, n_module_names);
+	free(module_names);
 	return ret;
 }
